@@ -1,5 +1,7 @@
 package App::CharmKit::Command::lint;
-$App::CharmKit::Command::lint::VERSION = '2.06';
+$App::CharmKit::Command::lint::VERSION = '2.07';
+# ABSTRACT: CharmKit Lint command
+
 
 use strict;
 use warnings;
@@ -29,7 +31,7 @@ __END__
 
 =head1 NAME
 
-App::CharmKit::Command::lint
+App::CharmKit::Command::lint - CharmKit Lint command
 
 =head1 SYNOPSIS
 
