@@ -1,5 +1,5 @@
 package App::CharmKit::HookUtil;
-$App::CharmKit::HookUtil::VERSION = '2.06';
+$App::CharmKit::HookUtil::VERSION = '2.07';
 # ABSTRACT: Additional helper hook routines
 
 use strict;
@@ -8,6 +8,7 @@ no warnings 'experimental::signatures';
 use feature 'signatures';
 use Rex::Commands::Run;
 use FindBin;
+use Module::Runtime qw(use_module);
 use base "Exporter::Tiny";
 
 our @EXPORT = qw(config resource unit status plugin);
@@ -34,10 +35,8 @@ sub status ($level = "active", $msg = "Ready") {
 }
 
 
-sub plugin($name, $opts={}) {
-    my $name_path = "$FindBin::Bin/../lib/$name.pm";
-    require $name_path;
-    return "$name"->new($opts);
+sub plugin($name) {
+    return use_module("$name");
 }
 
 
@@ -74,9 +73,9 @@ running charm
 
 Sets the charm's current status of execution
 
-=item plugin($name, %opts)
+=item plugin($name)
 
-Load a plugin, optionally passing options
+Load a plugin
 
 =back
 
