@@ -1,5 +1,7 @@
 package App::CharmKit::Role::Lint;
-$App::CharmKit::Role::Lint::VERSION = '2.06';
+$App::CharmKit::Role::Lint::VERSION = '2.07';
+# ABSTRACT: CharmKit Lint Role
+
 use strict;
 use warnings;
 no warnings 'experimental::signatures';
@@ -297,7 +299,7 @@ __END__
 
 =head1 NAME
 
-App::CharmKit::Role::Lint
+App::CharmKit::Role::Lint - CharmKit Lint Role
 
 =head1 SYNOPSIS
 
@@ -329,6 +331,10 @@ The format for rules is as follows:
         - pattern: '^options:\s*\n'
           error: 'ERR_INVALID_COPYRIGHT'
 
+=head1 TODO
+
+Switch to L<Module::Pluggable> for seperating out our checks.
+
 =head1 AUTHOR
 
 Adam Stokes <adamjs@cpan.org>
